@@ -78,6 +78,9 @@ macro_rules! llvm_asm {
     ("csrw mstatus, $0" : : "r" ($state:ident) : "memory" : "volatile") => {
         core::arch::asm!("csrw mstatus, {}", in(reg) $state);
     };
+    ("csrr $0, mstatus" : "=r" ($state:ident) : : "memory" : "volatile") => {
+        core::arch::asm!("csrr {}, mstatus", out(reg) $state);
+    };
     ($($x:tt)*) => {{
         llvm_asm_is_not_supported_any_more();
         unreachable!()
